import _extends from "@babel/runtime/helpers/esm/extends";
import { useState } from 'react';
import ReactSlidy from 'react-slidy';
import cx from 'classnames';
import PropTypes from 'prop-types';
import AtomImage from '@s-ui/react-atom-image';
import IconCamera from '@s-ui/react-icons/lib/Camera';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
export var IMAGE_SLIDER_COUNTER_POSITIONS = {
  BOTTOM_CENTER: 'bottomCenter',
  BOTTOM_LEFT: 'bottomLeft',
  BOTTOM_RIGHT: 'bottomRight'
};
export var IMAGE_SLIDER_CONTENT_TYPES = {
  IMAGE: 'image',
  NODE: 'node'
};
var NO_OP = function NO_OP() {};
var TARGET_BLANK = '_blank';
var defaultLinkFactory = function defaultLinkFactory(_ref // eslint-disable-line
) {
  var href = _ref.href,
    target = _ref.target,
    className = _ref.className,
    children = _ref.children,
    key = _ref.key;
  return /*#__PURE__*/_jsx("a", {
    href: href,
    target: target,
    className: className,
    children: children
  }, key);
};
var defaultCounterPatternFactory = function defaultCounterPatternFactory(_ref2) {
  var current = _ref2.current,
    total = _ref2.total;
  return current + "/" + total;
};

/**
 * @param {Array} images List given by props.images.
 * @return {Array} List of img or node elements.
 */
var getSlides = function getSlides(currentSlide, content, linkFactory) {
  if (content === void 0) {
    content = [];
  }
  return content.map(function (contentItem, index) {
    var alt = contentItem.alt,
      height = contentItem.height,
      imageKey = contentItem.key,
      link = contentItem.link,
      sources = contentItem.sources,
      src = contentItem.src,
      _contentItem$target = contentItem.target,
      target = _contentItem$target === void 0 ? TARGET_BLANK : _contentItem$target,
      title = contentItem.title,
      _contentItem$type = contentItem.type,
      type = _contentItem$type === void 0 ? IMAGE_SLIDER_CONTENT_TYPES.IMAGE : _contentItem$type,
      width = contentItem.width;
    var key = imageKey ? imageKey + index : index;
    var children = type === IMAGE_SLIDER_CONTENT_TYPES.IMAGE ? /*#__PURE__*/_jsx(AtomImage, {
      alt: alt,
      "aria-selected": currentSlide === index,
      className: "sui-ImageSlider-image",
      height: height,
      sources: sources,
      src: src,
      title: title,
      width: width
    }, key) : contentItem;
    return link ? linkFactory({
      key: key,
      target: target,
      className: '',
      children: children,
      href: link
    }) : children;
  });
};
export default function ImageSlider(_ref3) {
  var _ref3$images = _ref3.images,
    content = _ref3$images === void 0 ? [] : _ref3$images,
    _ref3$handleClick = _ref3.handleClick,
    handleClick = _ref3$handleClick === void 0 ? NO_OP : _ref3$handleClick,
    _ref3$sliderOptions = _ref3.sliderOptions,
    sliderOptions = _ref3$sliderOptions === void 0 ? {} : _ref3$sliderOptions,
    _ref3$linkFactory = _ref3.linkFactory,
    linkFactory = _ref3$linkFactory === void 0 ? defaultLinkFactory : _ref3$linkFactory,
    _ref3$enableCounter = _ref3.enableCounter,
    enableCounter = _ref3$enableCounter === void 0 ? false : _ref3$enableCounter,
    _ref3$counterPosition = _ref3.counterPosition,
    counterPosition = _ref3$counterPosition === void 0 ? IMAGE_SLIDER_COUNTER_POSITIONS.BOTTOM_RIGHT : _ref3$counterPosition,
    _ref3$counterIcon = _ref3.counterIcon,
    counterIcon = _ref3$counterIcon === void 0 ? IconCamera : _ref3$counterIcon,
    _ref3$counterPatternF = _ref3.counterPatternFactory,
    counterPatternFactory = _ref3$counterPatternF === void 0 ? defaultCounterPatternFactory : _ref3$counterPatternF;
  var _useState = useState(sliderOptions.initialSlide || 0),
    currentSlide = _useState[0],
    setCurrentSlide = _useState[1];
  var slides = getSlides(currentSlide, content, linkFactory);
  var hasSingleImage = slides.length === 1;
  var useFullHeight = sliderOptions.useFullHeight;
  var BASE_CLASS = cx('sui-ImageSlider', {
    'sui-ImageSlider--single': hasSingleImage,
    'sui-ImageSlider--fullHeight': useFullHeight
  });
  var buildCounter = function buildCounter(totalImages) {
    var classNames = cx('sui-ImageSlider-counter', "sui-ImageSlider-counter--" + counterPosition);
    var Icon = counterIcon;
    return /*#__PURE__*/_jsxs("div", {
      className: classNames,
      children: [/*#__PURE__*/_jsx(Icon, {
        svgClass: "sui-ImageSlider-counterIcon"
      }), /*#__PURE__*/_jsx("span", {
        className: "sui-ImageSlider-counterText",
        children: counterPatternFactory({
          current: currentSlide + 1,
          total: totalImages
        })
      })]
    });
  };
  var handleAfterSlide = function handleAfterSlide(_ref4) {
    var currentSlide = _ref4.currentSlide;
    setCurrentSlide(currentSlide);
    sliderOptions.doAfterSlide && sliderOptions.doAfterSlide(currentSlide);
  };
  return slides.length > 0 && /*#__PURE__*/_jsxs("div", {
    onClick: handleClick,
    className: BASE_CLASS,
    children: [slides.length > 1 ? /*#__PURE__*/_jsx(ReactSlidy, _extends({}, sliderOptions, {
      doAfterSlide: handleAfterSlide,
      children: slides
    })) : slides, enableCounter && buildCounter(slides.length)]
  });
}
ImageSlider.displayName = 'ImageSlider';